@@ -1,5 +1,6 @@
 from typing import Tuple, Any, ByteString
 import multiprocessing
+import time
 
 def run_worker(worker):
   while not worker._done:
@@ -28,8 +29,10 @@ class DistributedWorker:
     self.pipe = pipe
     self._done = False
     self.pipe.send(':register')
+    self.poll_delay = 0.1
   
   def run_once(self):
+    stime = time.time()
     self.loop()
 
     if self.pipe.poll(.1):
@@ -42,6 +45,9 @@ class DistributedWorker:
       else:
         self.handle_msg(msg)
 
+    # Delay up until poll_delay is reached (if needed)
+    time.sleep(max(stime - time.time() + self.poll_delay, 0))
+
   def send(self, msg: Any):
     self.pipe.send(msg)
 
